@@ -1,5 +1,7 @@
-/* Copyright Abandoned 1996, 1999, 2001 MySQL AB
-   This file is public domain and comes with NO WARRANTY of any kind */
+/* Copyright Abandoned 1996,1999 TCX DataKonsult AB & Monty Program KB
+   & Detron HB, 1996, 1999-2004, 2007 MySQL AB.
+   This file is public domain and comes with NO WARRANTY of any kind
+*/
 
 /* Version numbers for protocol & mysqld */
 
@@ -9,18 +11,22 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"10.0.1-MariaDB"
-#define MYSQL_BASE_VERSION		"mysqld-10.0"
-#define MARIADB_BASE_VERSION		"mariadb-10.0"
+#define MYSQL_SERVER_VERSION		"10.1.14-MariaDB"
+#define MYSQL_BASE_VERSION		"mysqld-10.1"
+#define MARIADB_BASE_VERSION		"mariadb-10.1"
 #define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		100001
+#define MYSQL_VERSION_ID		100114
 #define MYSQL_PORT			3306
 #define MYSQL_PORT_DEFAULT		0
 #define MYSQL_UNIX_ADDR			"/tmp/mysql.sock"
 #define MYSQL_CONFIG_NAME		"my"
 #define MYSQL_COMPILATION_COMMENT	"Source distribution"
 
+#ifdef WITH_WSREP
+#define WSREP_PATCH_VERSION             "wsrep_25.13"
+#endif
+
 /* mysqld compile time options */
 #endif /* _CUSTOMCONFIG_ */
 
